@@ -13,11 +13,9 @@ try:
     from numpy import squeeze
     from numpy import max as npmax
     from numpy import min as npmin
-    import requests as request_image
 except ImportError:
-    request_image = None
-    raise ImportError('Could not import PIL.Image. or Numpy '
-        'This library requires PIL >= 7.0.0 and numpy >= 1.18.1')
+    raise ImportError('Could not import PIL.Image. or Numpy'
+                          'this library requires PIL >= 7.0.0 and numpy >= 1.18.1')
 
 
 interpolation_methods = {
@@ -30,7 +28,7 @@ interpolation_methods = {
 }
 
 
-def imread(image_path,resize=None,color_mode = 'rgb',interpolation='nearest',dtype='float32',return_original = False):
+def imread(image_path,resize=None,color_mode = 'rgb',interpolation='nearest',dtype='float32'):
     """Converts a PIL Image instance to a Ndarray optimised for model.
     Parameters
     ----------
@@ -47,96 +45,38 @@ def imread(image_path,resize=None,color_mode = 'rgb',interpolation='nearest',dty
             "hamming" are also supported.
             Default: "nearest".
         dtype: Dtype to use for the returned array.
-
-        return_original: Returns original image array along with resized image array.
-        	Default: False
-        	Note: This parameter only works with resize parameter
     # Returns
         A 3D Numpy array.
     # Raises
         ValueError: if invalid `image_path` or `resize` or `color_mode` or `interpolation` or `dtype` is passed.
-        ValueError: if return_original is True and resize is None
     """
-    image = pilimage.open(image_path)
-    if color_mode == 'grayscale':
-        if image.mode not in ('L', 'I;16', 'I'):
-            image = image.convert('L')
-    elif color_mode == 'rgba':
-        if image.mode != 'RGBA':
-            image = image.convert('RGBA')
-    elif color_mode == 'rgb':
-        if image.mode != 'RGB':
-            image = image.convert('RGB')
-    else:
-        raise ValueError('color_mode must be "grayscale", "rgb", or "rgba"')
-        
-    if resize is not None:
-        if not isinstance(resize,tuple):
-            raise TypeError(f'resize must be tuple of (width,height) but got {resize} of type {type(resize)} instead')
-
-        if len(resize) != 2:
-            raise ValueError(f'Tuple with (width,height) required but got {resize} instead.')
-
-        original_image_array = toarray(image,dtype=dtype)
-        if image.size != resize:
-            if interpolation not in interpolation_methods:
-                raise ValueError(f'Invalid interpolation, currently supported interpolations:{interpolation_methods.keys()}')
-            resample = interpolation_methods.get(interpolation)
-            image = image.resize(resize, resample)
-    
-    image_array = toarray(image,dtype=dtype)
-    
-    if return_original:
-        if resize is None:
-            raise ValueError("return_original parameter only works with resize parameter")
-        return original_image_array , image_array
-    
-    return image_array
-
-
-def imurl(image_url, return_as_array = False , **kwargs):
-    """
-    Read image from url and convert to bytes or ndarray
-    
-    Paramters
-    ---------
-    image_url: http / https url of image
-    
-    return_as_array: Convert image directly to numpy array
-    	default: False
-    
-    kwargs:
-        Keyword arguments of imread can be passed for image modification:
-        Example:
-            imurl(image_url,to_array=True,resize=(224,224),color_mode = 'rgb',dtype='float32')
+    with pilimage.open(image_path) as image:
+        if color_mode == 'grayscale':
+            if image.mode not in ('L', 'I;16', 'I'):
+                image = image.convert('L')
+        elif color_mode == 'rgba':
+            if image.mode != 'RGBA':
+                image = image.convert('RGBA')
+        elif color_mode == 'rgb':
+            if image.mode != 'RGB':
+                image = image.convert('RGB')
+        else:
+            raise ValueError('color_mode must be "grayscale", "rgb", or "rgba"')
             
-        Note: kwargs only works with return_as_array = True
-        
-    Returns:
-        PIL Image by default:
-        if return_as_array is True:
-            image will be returned as numpy array.
-        
-        Additional params like resize, color_mode, dtype , return_original can also be passed inorder to refine the image
-    """
-    if request_image is None:
-        raise ImportError('requests library is required from reading image from url '
-                         'Install it using pip install requests')
-    
-    
-    if not image_url.startswith('http'):
-        raise ValueError(f'invalid url found. Required http or https url but got {image_url} instead')
-        
-        
-    image_response = request_image.get(image_url)
-    imbytes = BytesIO(image_response.content)
-    
-    if return_as_array:
-        return imread(imbytes,**kwargs)
-    
-    image = pilimage.open(imbytes)
-    
-    return image
+        if resize is not None:
+            if not isinstance(resize,tuple):
+                raise TypeError(f'resize must be tuple of (width,height) but got {resize} of type {type(resize)} instead')
+
+            if len(resize) != 2:
+                raise ValueError(f'Tuple with (width,height) required but got {resize} instead.')
+
+            if image.size != resize:
+                if interpolation not in interpolation_methods:
+                    raise ValueError(f'Invalid interpolation, currently supported interpolations:{interpolation_methods.keys()}')
+                resample = interpolation_methods.get(interpolation)
+                image = image.resize(resize, resample)
+                    
+    return toarray(image,dtype=dtype)
 
 
 def expand_dims(array,axis=0,normalize=False):
@@ -186,10 +126,10 @@ def get_image_from_array(img_array, denormalize=True, dtype='float32' ,is_cv2_im
             """expand image dimensions only if image is 2D grayscale
             manually adding channel dimension `1` to image (only for 2D grayscale image)"""
             img_array = expand_dims(img_array,axis=2)
-        else:
-            raise ValueError(f'Expected array with 3 dimensions Got array with shape {img_array.shape}\n'
-                'Incase you have used expand_dims for preprocessing, use nv.reduce_dims() for reducing expanded dimensions\n'
-                'make sure to check the axis position while expanding or reducing dimensions.')
+    else:
+        raise ValueError(f'Expected array with 3 dimensions Got array with shape {img_array.shape}\n'
+            'Incase you have used expand_dims for preprocessing, use nv.reduce_dims() for reducing expanded dimensions\n'
+            'make sure to check the axis position while expanding or reducing dimensions.')
 
     if is_cv2_image: #If numpy array is cv2 image
         img_array = img_array[...,::-1] #Convert BGR to RGB
@@ -227,8 +167,8 @@ def imshow(image,is_cv2_image=False):
     """
     if hasattr(image,'show'):
         image.show()
-    else:
-        get_image_from_array(image,is_cv2_image=is_cv2_image).show()
+    
+    get_image_from_array(image,is_cv2_image=is_cv2_image).show()
 
 
 def imsave(path,image,file_format = None ,is_cv2_image=False,denormalize=True,**kwargs):
@@ -245,12 +185,12 @@ def imsave(path,image,file_format = None ,is_cv2_image=False,denormalize=True,**
     """
     if hasattr(image,'save'): 
         image.save(path,file_format=file_format,**kwargs)
-    else:
-        image = get_image_from_array(image, denormalize=denormalize , is_cv2_image=is_cv2_image)
-        if image.mode == 'RGBA' and (file_format == 'jpg' or file_format == 'jpeg'):
-            warn('JPG format does not support RGBA images, converting to RGB.')
-            image = image.convert('RGB')
-        image.save(path, format=file_format, **kwargs)
+
+    image = get_image_from_array(image, denormalize=denormalize , is_cv2_image=is_cv2_image)
+    if image.mode == 'RGBA' and (file_format == 'jpg' or file_format == 'jpeg'):
+        warn('JPG format does not support RGBA images, converting to RGB.')
+        image = image.convert('RGB')
+    image.save(path, format=file_format, **kwargs)
 
 
 def reduce_dims(array,axis=0):
